import pytest
import sys

from ..lib.FTPconnector import FTPconnector

import logging

logger = logging.getLogger(__name__)

@pytest.fixture(
    name="FTPconnector"
)
def make_FTPconnector():
    return FTPconnector(
        host="ftp.us.debian.org",
        )

def test_connect(FTPconnector):
    FTPconnector.connect()
    assert True


import pytest
from ..lib.Convert_Soap_Rest import XML_JSON_XML

# Fixtures
@pytest.fixture
def converter():
    """
    Fixture to initialize an instance of XML_JSON_XML for testing.
    """
    return XML_JSON_XML()

# Path to the XML test file
file_path = (r'C:\Repos_Arion\ArionLibrary\processors\Convert_xml_json_xml\tests\Input_File_test\CERT.xml')

def test_detect_file_type_json(converter):
    """
    Test to verify if the detect_file_type method correctly detects JSON file type.

    Args:
        converter: Instance of XML_JSON_XML.
    """
    assert converter.detect_file_type(file_path) == 'json'


def test_convert_file_json(converter):
    """
    Test to verify if the convert_file method correctly converts a JSON file to XML.

    Args:
        converter: Instance of XML_JSON_XML.
    """
    # Convert the JSON file to XML using the convert_file method
    converter.convert_file(file_path)

# Tests
def test_detect_file_type_xml(converter):
    """
    Test to verify if the detect_file_type method correctly detects XML file type.

    Args:
        converter: Instance of XML_JSON_XML.
    """
    assert converter.detect_file_type(file_path) == 'xml'


def test_convert_file_xml(converter):
    """
    Test to verify if the convert_file method correctly converts an XML file to JSON.

    Args:
        converter: Instance of XML_JSON_XML.
    """
    # Convert the XML file to JSON using the convert_file method
    converter.convert_file(file_path)



import xmltodict
import json
import os

class XML_JSON_XML:
    """
    Class for conversion between XML and JSON formats.
    """

    def detect_file_type(self, file_path):
        """
        Determine the file type based on its extension.

        Args:
            file_path (str): Path of the file.

        Returns:
            str: File type ('xml', 'json') or None if the type is not supported.
        """
        file_extension = os.path.splitext(file_path)[1].lower()
        if file_extension == '.xml':
            return 'xml'
        elif file_extension == '.json':
            return 'json'
        else:
            return None

    def convert_xml_to_json(self, xml_content):
        """
        Convert XML content to JSON.

        Args:
            xml_content (str): XML content as a string.

        Returns:
            str: Resulting JSON content.
        """
        data_dict = xmltodict.parse(xml_content)
        json_data = json.dumps(data_dict, indent=4)
        return json_data

    def convert_json_to_xml(self, json_content):
        """
        Convert JSON content to XML.

        Args:
            json_content (str): JSON content as a string.

        Returns:
            str: Resulting XML content.
        """
        # Replace "None" with "null" in the JSON content
        json_content = json_content.replace("None", "null")

        # Parse JSON content
        data_list = json.loads(json_content)

        # Create XML string for each root item
        xml_data_list = []
        for item in data_list:
            xml_data_list.append(xmltodict.unparse({"root": item}, pretty=True))

        # Join XML strings
        xml_data = "\n".join(xml_data_list)
        return xml_data

    def convert_file(self, file_path):
        """
        Convert a file from the source format (XML or JSON) to the target format (JSON or XML).

        Args:
            file_path (str): Path of the source file.

        Raises:
            ValueError: If the file type is not supported.
        """
        file_type = self.detect_file_type(file_path)
        if file_type == 'xml':
            with open(file_path, 'r') as xml_file:
                xml_content = xml_file.read()
                json_data = self.convert_xml_to_json(xml_content)
                with open('Output.json', 'w') as json_file:
                    json_file.write(json_data)
            print("XML to JSON conversion successful.")
            print(json_data)
        elif file_type == 'json':
            with open(file_path, 'r') as json_file:
                json_content = json_file.read()
                xml_data = self.convert_json_to_xml(json_content)
                with open('Output.xml', 'w') as xml_file:
                    xml_file.write(xml_data)
            print("JSON to XML conversion successful.")
            print(xml_data)
        else:
            raise ValueError("Unsupported file type.")

# Example of using the class
xml_json_xml_instance = XML_JSON_XML()
xml_json_xml_instance.convert_file(r'C:\Repos_Arion\ArionLibrary\processors\Convert_xml_json_xml\tests\Input_File_test\CERT.xml')



import pytest
from ..lib.Handle_error_response import ErrorAPI

# Fixture to create an instance of the ErrorAPI class
@pytest.fixture
def error_api_instance():
    """
    Fixture to create an instance of the ErrorAPI class for testing.
    """
    return ErrorAPI()

# Test to verify the behavior of the _handle_error_response method
def test_handle_error_response(error_api_instance):
    """
    Test to verify the behavior of the _handle_error_response method.
    
    :param error_api_instance: Instance of the ErrorAPI class.
    """
    # Sample response containing an error message
    response = """
    <s:Envelope xmlns:s="http://schemas.xmlsoap.org/soap/envelope/">
        <s:Body>
            <s:Fault>
                <faultcode xmlns:a="http://www.cegid.fr/fault">a:CBR_001_0003</faultcode>
                <faultstring xml:lang="en-US">Remote call failed: Code = (WP006) Message = (WP006 : Failure during message execution (TWorkerMessageProcess.TryExecuteMessage))</faultstring>
                <detail>
                    <CbpExceptionDetail xmlns="http://www.cegid.fr/fault" xmlns:i="http://www.w3.org/2001/XMLSchema-instance">
                        <InnerException i:type="CbpExceptionDetail">
                            <InnerException i:type="CbpExceptionDetail">
                                <InnerException i:type="CbpExceptionDetail">
                                    <Message>Remote call failed: Code = (CBR00009) Message = (CBR00009 : Import failed : Customer order Internal reference LZD_EC04 DOC00042 - This document already exists and cannot be re-integrated (TCbrImportHelper.InvokeImport))</Message>
                                    <Type>Cegid.Retail.Tools.Resources.Biz001Exception</Type>
                                    <Id>CBR_001_0003</Id>
                                    <ToDo/>
                                </InnerException>
                                <Message>Remote call failed: Code = (CBR00006) Message = (CBR00006 : Failed to create document (TCbrImportHelper.CreateDocument))</Message>
                                <Type>Cegid.Retail.Tools.Resources.Biz001Exception</Type>
                                <Id>CBR_001_0003</Id>
                                <ToDo/>
                            </InnerException>
                            <Message>Remote call failed: Code = (WP008) Message = (WP008 : Operation 'Cegid.Retail.Documents.Sales.Create' failed calling 'TCbrImportHelper.CreateDocument' (TWorkerOperationDispatcher.Execute))</Message>
                            <Type>Cegid.Retail.Tools.Resources.Biz001Exception</Type>
                            <Id>CBR_001_0003</Id>
                            <ToDo/>
                        </InnerException>
                        <Message>Remote call failed: Code = (WP006) Message = (WP006 : Failure during message execution (TWorkerMessageProcess.TryExecuteMessage))</Message>
                        <TrackingId>f91de7f2-0c43-4cae-b8e3-4cad3f37811a</TrackingId>
                        <Type>Cegid.Retail.Tools.Resources.Biz001Exception</Type>
                        <Id>CBR_001_0003</Id>
                        <ToDo/>
                    </CbpExceptionDetail>
                </detail>
            </s:Fault>
        </s:Body>
    </s:Envelope>"""

    # Test with a response containing an error message
    result = error_api_instance._handle_error_response(response)
    print(result)  # Output the result


import logging
import xml.etree.ElementTree as ET

class ErrorAPI:
    def _handle_error_response(self, response):
        """
        Handle error response from the API and extract desired error messages.

        :param response: The response from the API.
        :type response: str
        :param id: The identifier associated with the request.
        :type id: str
        :return: Extracted error message or response text.
        :rtype: str
        """
        try:
            root = ET.fromstring(response)

            # Modified this line to directly access the root of the XML tree
            error_message_element = root.find(".//{http://www.cegid.fr/fault}Message")

            if error_message_element is not None:
                error_message = error_message_element.text
                error_message = error_message.split(":")[-1].strip()
                index = error_message.find("(TCbrImportHelper")

                if index != -1:
                    error_message = error_message[:index]
                    if "-" in error_message:
                        error_message = error_message.split('- ')[1].strip()

                    return error_message
                else:
                    return error_message  # Return error message if it's not None
            else:
                return response  # Return response text if no error message found
        except Exception as e:
            logging.error(f"Error handling response for: {str(e)}")
            return f'error message : {response}'

# Static response for testing
response = """<s:Envelope xmlns:s="http://schemas.xmlsoap.org/soap/envelope/">
    <s:Body>
        <s:Fault>
            <faultcode xmlns:a="http://www.cegid.fr/fault">a:CBR_001_0003</faultcode>
            <faultstring xml:lang="en-US">Remote call failed: Code = (WP006) Message = (WP006 : Failure during message execution (TWorkerMessageProcess.TryExecuteMessage))</faultstring>
            <detail>
                <CbpExceptionDetail xmlns="http://www.cegid.fr/fault" xmlns:i="http://www.w3.org/2001/XMLSchema-instance">
                    <InnerException i:type="CbpExceptionDetail">
                        <InnerException i:type="CbpExceptionDetail">
                            <InnerException i:type="CbpExceptionDetail">
                                <Message>Remote call failed: Code = (CBR00009) Message = (CBR00009 : Import failed : Customer order Internal reference LZD_EC04 DOC00042 - This document already exists and cannot be re-integrated (TCbrImportHelper.InvokeImport))</Message>
                                <Type>Cegid.Retail.Tools.Resources.Biz001Exception</Type>
                                <Id>CBR_001_0003</Id>
                                <ToDo/>
                            </InnerException>
                            <Message>Remote call failed: Code = (CBR00006) Message = (CBR00006 : Failed to create document (TCbrImportHelper.CreateDocument))</Message>
                            <Type>Cegid.Retail.Tools.Resources.Biz001Exception</Type>
                            <Id>CBR_001_0003</Id>
                            <ToDo/>
                        </InnerException>
                        <Message>Remote call failed: Code = (WP008) Message = (WP008 : Operation 'Cegid.Retail.Documents.Sales.Create' failed calling 'TCbrImportHelper.CreateDocument' (TWorkerOperationDispatcher.Execute))</Message>
                        <Type>Cegid.Retail.Tools.Resources.Biz001Exception</Type>
                        <Id>CBR_001_0003</Id>
                        <ToDo/>
                    </InnerException>
                    <Message>Remote call failed: Code = (WP006) Message = (WP006 : Failure during message execution (TWorkerMessageProcess.TryExecuteMessage))</Message>
                    <TrackingId>f91de7f2-0c43-4cae-b8e3-4cad3f37811a</TrackingId>
                    <Type>Cegid.Retail.Tools.Resources.Biz001Exception</Type>
                    <Id>CBR_001_0003</Id>
                    <ToDo/>
                </CbpExceptionDetail>
            </detail>
        </s:Fault>
    </s:Body>
</s:Envelope>"""

# Creating an instance of the ErrorAPI class
instance_error_api = ErrorAPI()

# Calling the _handle_error_response method with the static response and a fictitious id
result = instance_error_api._handle_error_response(response)

print(result)
